@@ -101,14 +101,14 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "annotated.html",
-"core_8h.html#a4c5b5cb41d6256b5262ca232f03ee6ef",
-"global_8h.html#ab6796dae933803798be1658f4020315c",
-"impl-node_8c.html#a9a92f81d55af5f321ec522182fd9ef7c",
-"link_8h.html#aa09465885f2b5edd3aecf62a2e8f7ef7",
-"pipewire_8c.html#ad6b599f28dfb2e60a14ac4cf01d4c18c",
-"stream_8h_source.html",
-"structpw__impl__client__events.html",
-"structpw__registry__events.html"
+"core_8h.html#a3c4c5529b9bb6c9188053bdf1604c2e0",
+"global_8h.html#a48ade1ac8c560225b6d54dedbc48836a",
+"impl-node_8c.html#a332223aa26f5d6c79181cf63e51b2bf6",
+"link_8h.html#a7859f6eb040fead1673d0214b83b445b",
+"permission_8h.html#a77df16320c3bb338666f55b2b21e6e47",
+"stream_8h.html#a55c1224289e488e27f8d3b6e58abcd08",
+"structpw__factory__info.html",
+"structpw__protocol__implementaton.html#a5dbc29661309ba54e93539eae72ba595"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
